==> kubernetes-annotations-2.6.0-sources.jar: io/dekorate/kubernetes/config/RollingUpdate.java <==
package io.dekorate.kubernetes.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @io.sundr.builder.annotations.Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class RollingUpdate{
  public RollingUpdate() {
  }
  public RollingUpdate(java.lang.String maxUnavailable,java.lang.String maxSurge) {
    this.maxUnavailable = maxUnavailable;
    this.maxSurge = maxSurge;
  }
  private java.lang.String maxUnavailable;
  private java.lang.String maxSurge;
  
  /**
   * Specifies the maximum number of Pods that can be unavailable during the update process.
   */
public java.lang.String getMaxUnavailable() {
    return this.maxUnavailable;
  }
  
  /**
   * Specifies the maximum number of Pods that can be created over the desired number of Pods.
   */
public java.lang.String getMaxSurge() {
    return this.maxSurge;
  }
  public static io.dekorate.kubernetes.config.RollingUpdateBuilder newBuilder() {
    return new io.dekorate.kubernetes.config.RollingUpdateBuilder();
  }
  public static io.dekorate.kubernetes.config.RollingUpdateBuilder newBuilderFromDefaults() {
    return new io.dekorate.kubernetes.config.RollingUpdateBuilder().withMaxUnavailable("25%").withMaxSurge("25%");
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdate that = (RollingUpdate) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  maxSurge,  super.hashCode());
  }
  
}

==> kubernetes-annotations-2.11.3-sources.jar: io/dekorate/kubernetes/config/RollingUpdate.java <==
package io.dekorate.kubernetes.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class RollingUpdate{
  public RollingUpdate() {
  }
  public RollingUpdate(String maxUnavailable,java.lang.String maxSurge) {
    this.maxUnavailable = maxUnavailable;
    this.maxSurge = maxSurge;
  }
  private java.lang.String maxUnavailable;
  private java.lang.String maxSurge;
  
  /**
   * Specifies the maximum number of Pods that can be unavailable during the update process.
   */
public java.lang.String getMaxUnavailable() {
    return this.maxUnavailable;
  }
  
  /**
   * Specifies the maximum number of Pods that can be created over the desired number of Pods.
   */
public java.lang.String getMaxSurge() {
    return this.maxSurge;
  }
  public static RollingUpdateBuilder newBuilder() {
    return new RollingUpdateBuilder();
  }
  public static io.dekorate.kubernetes.config.RollingUpdateBuilder newBuilderFromDefaults() {
    return new io.dekorate.kubernetes.config.RollingUpdateBuilder().withMaxUnavailable("25%").withMaxSurge("25%");
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdate that = (RollingUpdate) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  maxSurge,  super.hashCode());
  }
  
}
